@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: error.c 3217 2007-02-24 17:21:19Z roms $ */
+/* $Id: error.c 4247 2009-05-05 20:59:01Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Livin
@@ -28,9 +28,13 @@
 #include "error.h"
 #include "logging.h"
 
-extern void vtl_pkt_purge(void);
+// extern helpers
+extern void dusb_vtl_pkt_purge(void);
+extern void nsp_vtl_pkt_purge(void);
 extern void cpca_purge(void);
 
+extern int nsp_reset;
+
 /**
  * ticalcs_error_get:
  * @number: error number (see error.h for list).
@@ -49,8 +53,14 @@ TIEXPORT3 int TICALL ticalcs_error_get(CalcError number, char **message)
 {
 	char error_msg[2048];
 
-	vtl_pkt_purge();
+	// free memory
+	dusb_vtl_pkt_purge();
 	cpca_purge();
+	nsp_vtl_pkt_purge();
+
+	// force reset/address request
+	//ticalcs_info("force reset !\n");
+	nsp_reset = 0;
 
 	g_assert (message != NULL);
 
@@ -237,7 +247,7 @@ case ERR_OUT_OF_MEMORY:
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
-		   ("Cause: hand-held returned an uncatched error. Please report log."));
+		   ("Cause: hand-held returned an uncaught error. Please report log."));
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR1+1:
@@ -261,20 +271,20 @@ case ERR_OUT_OF_MEMORY:
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR1+6:
-		strcpy(error_msg, _("Msg: invalid folder name."));
+		strcpy(error_msg, _("Msg: malformed RTS packet (AMS version conflict)."));
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR1+7:
-		strcpy(error_msg, _("Msg: malformed RTS packet (AMS version conflict)."));
+		strcpy(error_msg, _("Msg: FLASH application rejected (signature does not match)."));
 		*message = g_strdup(error_msg);
     break;
 
   case ERR_CALC_ERROR2:	// must be synch'ed with dusb_cmd.c (static uint16_t usb_errors[])
-		strcpy(error_msg, _("Msg: hand-held returned an error (not catched)."));
+		strcpy(error_msg, _("Msg: hand-held returned an error (not caught)."));
 		strcat(error_msg, "\n");
 		strcat(error_msg,
 		   _
-		   ("Cause: hand-held returned an uncatched error. Please report log."));
+		   ("Cause: hand-held returned an uncaught error. Please report log."));
 		*message = g_strdup(error_msg);
     break;
   case ERR_CALC_ERROR2+1:
@@ -338,6 +348,43 @@ case ERR_OUT_OF_MEMORY:
 		*message = g_strdup(error_msg);
     break;
 
+  case ERR_CALC_ERROR3+0:
+		strcpy(error_msg, _("Msg: hand-held returned an error (not caught)."));
+		strcat(error_msg, "\n");
+		strcat(error_msg,
+		   _
+		   ("Cause: hand-held returned an uncaught error. Please report log."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+1:
+	    strcpy(error_msg, _("Msg: OS installation failed. File is corrupted/wrong."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+2:
+	    strcpy(error_msg, _("Msg: the directory does not exist."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+3:
+	    strcpy(error_msg, _("Msg: the directory name is invalid."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+4:
+	    strcpy(error_msg, _("Msg: not currently listing a directory."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+5:
+	    strcpy(error_msg, _("Msg: no more files to list."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+6:
+	    strcpy(error_msg, _("Msg: the file name is invalid."));
+		*message = g_strdup(error_msg);
+    break;
+	case ERR_CALC_ERROR3+7:
+	    strcpy(error_msg, _("Msg: no file extension."));
+		*message = g_strdup(error_msg);
+    break;
+
 	default:
 		// propagate error code
 	    return number;
