@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ticalcs.h 3525 2007-06-26 13:31:39Z roms $ */
+/* $Id: ticalcs.h 4247 2009-05-05 20:59:01Z roms $ */
 
 /*  libticables - hand-helds support library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -43,13 +43,13 @@ extern "C" {
 /* Versioning */
 
 #ifdef __WIN32__
-# define LIBCALCS_VERSION "1.0.7"
+# define LIBCALCS_VERSION "1.1.4"
 #else
 # define LIBCALCS_VERSION VERSION
 #endif
 
-#define LIBCALCS_REQUIRES_LIBFILES_VERSION		"1.0.7"	// useless with pkg-config
-#define LIBCALCS_REQUIRES_LIBTICABLES_VERSION	"1.0.4"	// useless with pkg-config
+#define LIBCALCS_REQUIRES_LIBTIFILES_VERSION	"1.1.0"	// useless with pkg-config
+#define LIBCALCS_REQUIRES_LIBTICABLES_VERSION	"1.2.0"	// useless with pkg-config
 
 /* Types */
 
@@ -70,7 +70,7 @@ typedef enum
 	CALC_NONE = 0,
 	CALC_TI73, CALC_TI82, CALC_TI83, CALC_TI83P, CALC_TI84P, CALC_TI85, CALC_TI86,
 	CALC_TI89, CALC_TI89T, CALC_TI92, CALC_TI92P, CALC_V200,
-	CALC_TI84P_USB, CALC_TI89T_USB,
+	CALC_TI84P_USB, CALC_TI89T_USB, CALC_NSPIRE, CALC_MAX
 } CalcModel;
 #endif
 
@@ -206,9 +206,9 @@ typedef enum
  **/
 typedef enum 
 {
-	INFOS_PRODUCT_NUMBER = (1 << 0), 
+	INFOS_PRODUCT_NUMBER = (1 << 0), /* obsolete (never used) */
 	INFOS_PRODUCT_NAME	= (1 << 1),
-	INFOS_MAIN_CALC_ID	= (1 << 2),
+	INFOS_MAIN_CALC_ID	= (1 << 2),	 /* obsolete, replaced by INFOS_PRODUCT_ID */
 	INFOS_HW_VERSION	= (1 << 3),
 	INFOS_LANG_ID		= (1 << 4),
 	INFOS_SUB_LANG_ID	= (1 << 5),
@@ -224,6 +224,11 @@ typedef enum
 	INFOS_LCD_WIDTH		= (1 << 15),
 	INFOS_LCD_HEIGHT	= (1 << 16),
 	INFOS_BATTERY		= (1 << 17),	
+	INFOS_BOOT2_VERSION	= (1 << 18),
+	INFOS_RUN_LEVEL		= (1 << 19),
+	INFOS_BPP			= (1 << 20),
+	INFOS_CLOCK_SPEED	= (1 << 21),
+	INFOS_PRODUCT_ID	= (1 << 22),
 
 	INFOS_CALC_MODEL	= (1 << 31),
 } InfosMask;
@@ -289,11 +294,11 @@ typedef struct
 {
 	int		format;
 
-	uint8_t width;
-	uint8_t height;
+	unsigned int width;
+	unsigned int height;
 
-	uint8_t clipped_width;
-	uint8_t clipped_height;
+	unsigned int clipped_width;
+	unsigned int clipped_height;
 } CalcScreenCoord;
 
 /**
@@ -397,9 +402,9 @@ typedef struct
  * @text: a text to display about the current operation (locale used is those defined by tifiles_transcoding_set)
  * @cancel: set to 1 if transfer have to be cancelled
  * @rate: data rate of cable
- * @cnt1: current counter for link transfer operations (ticables2)
+ * @cnt1: current counter for link transfer operations (ticalcs2 only)
  * @max1: max value of this counter
- * @cnt2: current count for intermediate operations (used by ticalcs2 only)
+ * @cnt2: current count for intermediate operations (ticalcs2 only)
  * @max2: max value of this counter
  * @cnt3: current counter for global operations (used by ticalcs2 or tilp)
  * @max3: max value of this counter
@@ -462,15 +467,20 @@ typedef VarEntry	VarRequest;	// alias
  **/
 typedef struct 
 {
-	uint32_t	product_number;
-	char		product_name[65];
-	char		main_calc_id[11];
-	uint16_t	hw_version;
+	CalcModel	model;
+	InfosMask	mask;
+
+	char		product_name[64];
+	char		product_id[32];
+	uint32_t	product_number;		// obsolete, replaced by product_id
+	char		main_calc_id[32];	// obsolete, replaced by product_id
+	uint16_t	hw_version;			// hand-held dependent
 	uint8_t		language_id;
 	uint8_t		sub_lang_id;
-	uint16_t	device_type;
-	char		boot_version[5];
-	char		os_version[5];
+	uint16_t	device_type;		// hand-held dependent
+	char		boot_version[10];
+	char		boot2_version[10];
+	char		os_version[10];
 	uint64_t	ram_phys;
 	uint64_t	ram_user;
 	uint64_t	ram_free;
@@ -479,11 +489,10 @@ typedef struct
 	uint64_t	flash_free;
 	uint16_t	lcd_width;
 	uint16_t	lcd_height;
-	uint8_t		battery;
-
-	CalcModel	model;
-
-	InfosMask	mask;
+	uint8_t		battery;			// 0 = low, 1 = good
+	uint8_t		run_level;			// 1 = boot, 2 = OS
+	uint16_t	bits_per_pixel;		// 1 or 4
+	uint16_t	clock_speed;
 } CalcInfos;
 
 /**
